@@ -6,3 +6,6 @@ if use_gpu:
     import cupy as np
 else:
     import numpy as np
+    np.seterr(divide='ignore')
+
+np
\ No newline at end of file
