@@ -1,13 +1,13 @@
 import copy
 from collections import deque
 
-from klongpy.adverbs import get_adverb_fn
-from klongpy.core import *
-from klongpy.dyads import create_dyad_functions
-from klongpy.monads import create_monad_functions
-from klongpy.sys_fn import create_system_functions
-from klongpy.sys_var import *
-from klongpy.utils.ro_dict import ReadonlyDict
+from .adverbs import get_adverb_fn
+from .core import *
+from .dyads import create_dyad_functions
+from .monads import create_monad_functions
+from .sys_fn import create_system_functions
+from .sys_var import *
+from .utils import ReadonlyDict
 
 
 def set_context_var(d, name, v):
